@@ -10,16 +10,16 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27-67vl5.src.rpm ]
+if [ ! -r kernel-2.6.27-71vl5.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-5.2/updates/SRPMS/kernel-2.6.27-67vl5.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-5.2/updates/SRPMS/kernel-2.6.27-71vl5.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27-67vl5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.27-71vl5.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.9-20110411.tar.gz ]
+if [ ! -r ccs-patch-1.6.9-20110903.tar.gz ]
 then
-    wget -O ccs-patch-1.6.9-20110411.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20110411.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.6.9-20110903.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20110903.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -28,11 +28,11 @@ patch << "EOF" || die "Can't patch spec file."
 --- kernel-2.6-vl.spec
 +++ kernel-2.6-vl.spec
 @@ -27,7 +27,7 @@
- %define patchlevel 55
+ %define patchlevel 59
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 67%{?_dist_release}
-+%define release 67%{?_dist_release}_tomoyo_1.6.9
+-%define release 71%{?_dist_release}
++%define release 71%{?_dist_release}_tomoyo_1.6.9p1
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
@@ -60,7 +60,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.9-20110411.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.9-20110903.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.2.diff
 +
  cp %{SOURCE10} Documentation/
