@@ -3,9 +3,9 @@
  *
  * Get the canonicalized absolute pathnames. The basis for SAKURA and TOMOYO.
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.6.6   2009/02/02
+ * Version: 1.6.9   2011/04/01
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -17,9 +17,10 @@
 
 struct dentry;
 struct vfsmount;
-struct condition_list;
-struct path_info;
+struct ccs_condition_list;
+struct ccs_path_info;
 struct ccs_io_buffer;
+struct ccs_execve_entry;
 
 /* Returns realpath(3) of the given pathname but ignores chroot'ed root. */
 int ccs_realpath_from_dentry2(struct dentry *dentry, struct vfsmount *mnt,
@@ -31,10 +32,12 @@ int ccs_realpath_from_dentry2(struct dentry *dentry, struct vfsmount *mnt,
  * if these functions didn't return NULL.
  */
 char *ccs_realpath(const char *pathname);
-/* Same with ccs_realpath() except that it doesn't follow the final symlink. */
-char *ccs_realpath_nofollow(const char *pathname);
+/* Get ccs_realpath() of both symlink and dereferenced pathname. */
+int ccs_realpath_both(const char *pathname, struct ccs_execve_entry *ee);
 /* Same with ccs_realpath() except that the pathname is already solved. */
 char *ccs_realpath_from_dentry(struct dentry *dentry, struct vfsmount *mnt);
+/* Encode binary string to ascii string. */
+char *ccs_encode(const char *str);
 
 /*
  * Allocate memory for ACL entry.
@@ -46,10 +49,10 @@ void *ccs_alloc_element(const unsigned int size);
  * Keep the given name on the RAM.
  * The RAM is shared, so NEVER try to modify or kfree() the returned name.
  */
-const struct path_info *ccs_save_name(const char *name);
+const struct ccs_path_info *ccs_save_name(const char *name);
 
 /* Allocate memory for temporary use (e.g. permission checks). */
-void *ccs_alloc(const size_t size);
+void *ccs_alloc(const size_t size, const _Bool check_quota);
 
 /* Free memory allocated by ccs_alloc(). */
 void ccs_free(const void *p);
