@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Based Mandatory Access Control.
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.6.7   2009/04/01
+ * Version: 1.6.9   2011/04/01
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -1347,6 +1347,11 @@ int ccs_check_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 	const u8 acc_mode = ACC_MODE(flag);
 	int error = -ENOMEM;
 	struct ccs_path_info *buf;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 30)
+	if (current->in_execve &&
+	    !(current->ccs_flags & CCS_CHECK_READ_FOR_OPEN_EXEC))
+		return 0;
+#endif
 	if (!ccs_can_sleep())
 		return 0;
 	ccs_init_request_info(&r, current->ccs_flags &
@@ -1398,19 +1403,22 @@ int ccs_check_open_permission(struct dentry *dentry, struct vfsmount *mnt,
  * @operation: Type of operation.
  * @dentry:    Pointer to "struct dentry".
  * @mnt:       Pointer to "struct vfsmount".
+ * @target:    Symlink's target if @operation is TYPE_SYMLINK_ACL.
  *
  * Returns 0 on success, negative value otherwise.
  */
 static int ccs_check_1path_perm(const u8 operation, struct dentry *dentry,
-				struct vfsmount *mnt)
+				struct vfsmount *mnt, const char *target)
 {
 	struct ccs_request_info r;
 	struct ccs_obj_info obj;
 	int error = -ENOMEM;
 	struct ccs_path_info *buf;
 	bool is_enforce;
+	struct ccs_path_info symlink_target;
 	if (!ccs_can_sleep())
 		return 0;
+	symlink_target.name = NULL;
 	ccs_init_request_info(&r, NULL, CCS_MAC_FOR_FILE);
 	is_enforce = (r.mode == 3);
 	if (!r.mode || !mnt)
@@ -1430,8 +1438,17 @@ static int ccs_check_1path_perm(const u8 operation, struct dentry *dentry,
 	memset(&obj, 0, sizeof(obj));
 	obj.path1_dentry = dentry;
 	obj.path1_vfsmnt = mnt;
+	if (operation == TYPE_SYMLINK_ACL) {
+		symlink_target.name = ccs_encode(target);
+		if (!symlink_target.name)
+			goto out;
+		ccs_fill_path_info(&symlink_target);
+		obj.symlink_target = &symlink_target;
+	}
 	r.obj = &obj;
 	error = ccs_check_single_path_permission2(&r, operation, buf);
+	if (operation == TYPE_SYMLINK_ACL)
+		ccs_free(symlink_target.name);
  out:
 	ccs_free(buf);
 	if (!is_enforce)
@@ -1783,7 +1800,7 @@ int ccs_write_ioctl_policy(char *data, struct ccs_domain_info *domain,
 /**
  * ccs_check_ioctl_permission - Check permission for "ioctl".
  *
- * @file: Pointer to "struct file".
+ * @filp: Pointer to "struct file".
  * @cmd:  Ioctl command number.
  * @arg:  Param for @cmd .
  *
@@ -2278,7 +2295,7 @@ int ccs_check_mknod_permission(struct inode *dir, struct dentry *dentry,
 		error = ccs_pre_vfs_create(dir, dentry);
 		if (!error)
 			error = ccs_check_1path_perm(TYPE_CREATE_ACL,
-						     dentry, mnt);
+						     dentry, mnt, NULL);
 		return error;
 	}
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
@@ -2290,16 +2307,20 @@ int ccs_check_mknod_permission(struct inode *dir, struct dentry *dentry,
 		return error;
 	switch (mode & S_IFMT) {
 	case S_IFCHR:
-		error = ccs_check_1path_perm(TYPE_MKCHAR_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_MKCHAR_ACL, dentry, mnt,
+					     NULL);
 		break;
 	case S_IFBLK:
-		error = ccs_check_1path_perm(TYPE_MKBLOCK_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_MKBLOCK_ACL, dentry, mnt,
+					     NULL);
 		break;
 	case S_IFIFO:
-		error = ccs_check_1path_perm(TYPE_MKFIFO_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_MKFIFO_ACL, dentry, mnt,
+					     NULL);
 		break;
 	case S_IFSOCK:
-		error = ccs_check_1path_perm(TYPE_MKSOCK_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_MKSOCK_ACL, dentry, mnt,
+					     NULL);
 		break;
 	}
 	return error;
@@ -2312,7 +2333,7 @@ int ccs_check_mkdir_permission(struct inode *dir, struct dentry *dentry,
 {
 	int error = ccs_pre_vfs_mkdir(dir, dentry);
 	if (!error)
-		error = ccs_check_1path_perm(TYPE_MKDIR_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_MKDIR_ACL, dentry, mnt, NULL);
 	return error;
 }
 
@@ -2322,7 +2343,7 @@ int ccs_check_rmdir_permission(struct inode *dir, struct dentry *dentry,
 {
 	int error = ccs_pre_vfs_rmdir(dir, dentry);
 	if (!error)
-		error = ccs_check_1path_perm(TYPE_RMDIR_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_RMDIR_ACL, dentry, mnt, NULL);
 	return error;
 }
 
@@ -2335,7 +2356,8 @@ int ccs_check_unlink_permission(struct inode *dir, struct dentry *dentry,
 		return -EPERM;
 	error = ccs_pre_vfs_unlink(dir, dentry);
 	if (!error)
-		error = ccs_check_1path_perm(TYPE_UNLINK_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_UNLINK_ACL, dentry, mnt,
+					     NULL);
 	return error;
 }
 
@@ -2348,7 +2370,8 @@ int ccs_check_symlink_permission(struct inode *dir, struct dentry *dentry,
 		return -EPERM;
 	error = ccs_pre_vfs_symlink(dir, dentry);
 	if (!error)
-		error = ccs_check_1path_perm(TYPE_SYMLINK_ACL, dentry, mnt);
+		error = ccs_check_1path_perm(TYPE_SYMLINK_ACL, dentry, mnt,
+					     from);
 	return error;
 }
 
@@ -2356,7 +2379,7 @@ int ccs_check_symlink_permission(struct inode *dir, struct dentry *dentry,
 int ccs_check_truncate_permission(struct dentry *dentry, struct vfsmount *mnt,
 				  loff_t length, unsigned int time_attrs)
 {
-	return ccs_check_1path_perm(TYPE_TRUNCATE_ACL, dentry, mnt);
+	return ccs_check_1path_perm(TYPE_TRUNCATE_ACL, dentry, mnt, NULL);
 }
 
 /* Permission checks for vfs_rename(). */
@@ -2390,6 +2413,7 @@ int ccs_check_link_permission(struct dentry *old_dentry, struct inode *new_dir,
 	return error;
 }
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 30)
 /* Permission checks for open_exec(). */
 int ccs_check_open_exec_permission(struct dentry *dentry, struct vfsmount *mnt)
 {
@@ -2404,6 +2428,7 @@ int ccs_check_uselib_permission(struct dentry *dentry, struct vfsmount *mnt)
 	/* 01 means "read". */
 	return ccs_check_open_permission(dentry, mnt, 01);
 }
+#endif
 
 #if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 18) || defined(CONFIG_SYSCTL_SYSCALL)
 
